Parametric Rao's index of quadratic entropy (Q).
paRaoS(rasterm,alpha,w,dist_m,na.tolerance,
diag,debugging,isfloat,mfactor)A list of matrices of dimension dim(x) with length equal to the length of alpha.
input data.
alpha value for order of diversity in Hill's Index.
half of the side of the square moving window.
Type of distance used.
a numeric value \((0.0-1.0)\) which indicates the proportion of NA values that will be tolerated to calculate Rao's index in each moving window over x. If the relative proportion of NA's in a moving window is bigger than na.tolerance, then the value of the window will be set as NA, otherwise Rao's index will be calculated considering the non-NA values. Default values is 0.0 (i.e., no tolerance for NA's).
Boolean. Diagonal of the distance matrix.
a boolean variable set to FALSE by default. If TRUE, additional messages will be printed. For de-bugging only.
Are the input data floats?
Duccio Rocchini duccio.rocchini@unibo.it
Marcantonio Matteo marcantoniomatteo@gmail.com
paRao